@@ -15,13 +15,15 @@ from .vars import (
     ACCESSION_PREFIX,
     HIGLASS_BUCKETS
 )
-from tibanna_ffcommon.portal_utils import (
+from tibanna_ffcommon.wfr import (
     WorkflowRunMetadataAbstract,
+    aslist
+)
+from tibanna_ffcommon.portal_utils import (
     ProcessedFileMetadataAbstract,
     FourfrontUpdaterAbstract,
     FFInputAbstract,
     FourfrontStarterAbstract,
-    aslist
 )
 
 
@@ -117,13 +119,14 @@ class FourfrontUpdater(FourfrontUpdaterAbstract):
     default_email_sender = '4dndcic@gmail.com'
     higlass_buckets = HIGLASS_BUCKETS
 
-    def create_qc_template(self):
-        res = super().create_qc_template()
-        if 'award' not in res:
-            res.update({"award": DEFAULT_AWARD})
-        if 'lab' not in res:
-            res.update({"lab": DEFAULT_LAB})
-        return res
+    def qc_template_generator(self, add_custom_qc_fields=False):
+        while(True):
+            res = next(super().qc_template_generator(add_custom_qc_fields=add_custom_qc_fields))
+            if 'award' not in res:
+                res.update({"award": DEFAULT_AWARD})
+            if 'lab' not in res:
+                res.update({"lab": DEFAULT_LAB})
+            yield res
 
 
 def post_random_file(bucket, ff_key,
